@@ -23,7 +23,8 @@
 #ifndef __PANGOCORETEXT_H__
 #define __PANGOCORETEXT_H__
 
-#include <pango/pango.h>
+#include <pango/pango-context.h>
+#include <pango/pango-font.h>
 #include <Carbon/Carbon.h>
 
 G_BEGIN_DECLS
@@ -35,13 +36,45 @@ G_BEGIN_DECLS
 typedef struct _PangoCoreTextFont         PangoCoreTextFont;
 typedef struct _PangoCoreTextFontClass    PangoCoreTextFontClass;
 
+#if defined(PANGO_ENABLE_ENGINE) || defined(PANGO_ENABLE_BACKEND)
 
-PANGO_AVAILABLE_IN_ALL
-GType      pango_core_text_font_get_type         (void) G_GNUC_CONST;
+#define PANGO_RENDER_TYPE_CORE_TEXT "PangoRenderCoreText"
+
+#ifdef PANGO_ENABLE_BACKEND
+
+#define PANGO_CORE_TEXT_FONT_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), PANGO_TYPE_CORE_TEXT_FONT, PangoCoreTextFontClass))
+#define PANGO_IS_CORE_TEXT_FONT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PANGO_TYPE_CORE_TEXT_FONT))
+#define PANGO_CORE_TEXT_FONT_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), PANGO_TYPE_CORE_TEXT_FONT, PangoCoreTextFontClass))
+
+typedef struct _PangoCoreTextFontPrivate  PangoCoreTextFontPrivate;
+
+struct _PangoCoreTextFont
+{
+  PangoFont parent_instance;
+  PangoCoreTextFontPrivate *priv;
+};
+
+struct _PangoCoreTextFontClass
+{
+  PangoFontClass parent_class;
+
+  /*< private >*/
+
+  /* Padding for future expansion */
+  void (*_pango_reserved1) (void);
+  void (*_pango_reserved2) (void);
+  void (*_pango_reserved3) (void);
+  void (*_pango_reserved4) (void);
+};
+
+#endif /* PANGO_ENABLE_BACKEND */
 
-PANGO_AVAILABLE_IN_1_24
 CTFontRef  pango_core_text_font_get_ctfont  (PangoCoreTextFont *font);
 
+#endif /* PANGO_ENABLE_ENGINE || PANGO_ENABLE_BACKEND */
+
+GType      pango_core_text_font_get_type         (void) G_GNUC_CONST;
+
 G_END_DECLS
 
 #endif /* __PANGOCORETEXT_H__ */
