@@ -19,36 +19,6 @@
  * Boston, MA 02111-1307, USA.
  */
 
-/**
- * SECTION:xft-fonts
- * @short_description:Font handling and rendering with the Xft backend
- * @title:Xft Fonts and Rendering
- *
- * The Xft library is a library for displaying fonts on the X window
- * system; internally it uses the fontconfig library to locate font
- * files, and the FreeType library to load and render fonts. The
- * Xft backend is the recommended Pango font backend for screen
- * display with X. (The <link linkend="pango-Cairo-Rendering">Cairo back end</link> is another possibility.)
- *
- * Using the Xft backend is generally straightforward;
- * pango_xft_get_context() creates a context for a specified display
- * and screen. You can then create a #PangoLayout with that context
- * and render it with pango_xft_render_layout(). At a more advanced
- * level, the low-level fontconfig options used for rendering fonts
- * can be affected using pango_xft_set_default_substitute(), and
- * pango_xft_substitute_changed().
- *
- * A range of functions for drawing pieces of a layout, such as
- * individual layout lines and glyphs strings are provided.  You can also
- * directly create a #PangoXftRenderer. Finally, in some advanced cases, it
- * is useful to derive from #PangoXftRenderer. Deriving from
- * #PangoXftRenderer is useful for two reasons. One reason is be to
- * support custom attributes by overriding #PangoRendererClass virtual
- * functions like 'prepare_run' or 'draw_shape'. The reason is to
- * customize exactly how the final bits are drawn to the destination by
- * overriding the #PangoXftRendererClass virtual functions
- * 'composite_glyphs' and 'composite_trapezoids'.
- */
 #include "config.h"
 
 #include <stdlib.h>
@@ -331,6 +301,7 @@ get_glyph_extents_raw (PangoXftFont     *xfont,
       extents = g_slice_new (Extents);
 
       pango_fc_font_get_raw_extents (PANGO_FC_FONT (xfont),
+				     FT_LOAD_NO_BITMAP | FT_LOAD_NO_HINTING,
 				     glyph,
 				     &extents->ink_rect,
 				     &extents->logical_rect);
@@ -499,13 +470,12 @@ pango_xft_font_real_shutdown (PangoFcFont *fcfont)
 }
 
 /**
- * pango_xft_font_get_font: (skip)
- * @font: (nullable): a #PangoFont.
+ * pango_xft_font_get_font:
+ * @font: a #PangoFont.
  *
- * Returns the `XftFont` of a font.
+ * Returns the XftFont of a font.
  *
- * Return value: (nullable): the `XftFont` associated to @font,
- *   or %NULL if @font is %NULL.
+ * Return value: the XftFont associated to @font, or %NULL if @font is %NULL.
  **/
 XftFont *
 pango_xft_font_get_font (PangoFont *font)
@@ -517,12 +487,12 @@ pango_xft_font_get_font (PangoFont *font)
 }
 
 /**
- * pango_xft_font_get_display: (skip)
- * @font: (type PangoXftFont): a #PangoFont.
+ * pango_xft_font_get_display:
+ * @font: a #PangoFont.
  *
- * Returns the X display of the `XftFont` of a font.
+ * Returns the X display of the XftFont of a font.
  *
- * Return value: (transfer none): the X display of the XftFont associated to @font.
+ * Return value: the X display of the XftFont associated to @font.
  **/
 Display *
 pango_xft_font_get_display (PangoFont *font)
@@ -540,7 +510,7 @@ pango_xft_font_get_display (PangoFont *font)
 
 /**
  * pango_xft_font_get_unknown_glyph:
- * @font: (type PangoXftFont): a #PangoFont.
+ * @font: a #PangoFont.
  * @wc: the Unicode character for which a glyph is needed.
  *
  * Returns the index of a glyph suitable for drawing @wc as an
@@ -560,16 +530,16 @@ pango_xft_font_get_unknown_glyph (PangoFont *font,
 }
 
 /**
- * pango_xft_font_lock_face: (skip)
- * @font: (type PangoXftFont): a #PangoFont.
+ * pango_xft_font_lock_face:
+ * @font: a #PangoFont.
  *
- * Gets the FreeType `FT_Face` associated with a font.
- *
- * This face will be kept around until you call pango_xft_font_unlock_face().
+ * Gets the FreeType <type>FT_Face</type> associated with a font,
+ * This face will be kept around until you call
+ * pango_xft_font_unlock_face().
  *
  * Use pango_fc_font_lock_face() instead.
  *
- * Return value: the FreeType `FT_Face` associated with @font.
+ * Return value: the FreeType <type>FT_Face</type> associated with @font.
  *
  * Since: 1.2
  **/
@@ -582,8 +552,8 @@ pango_xft_font_lock_face (PangoFont *font)
 }
 
 /**
- * pango_xft_font_unlock_face: (skip)
- * @font: (type PangoXftFont): a #PangoFont.
+ * pango_xft_font_unlock_face:
+ * @font: a #PangoFont.
  *
  * Releases a font previously obtained with
  * pango_xft_font_lock_face().
@@ -602,7 +572,7 @@ pango_xft_font_unlock_face (PangoFont *font)
 
 /**
  * pango_xft_font_get_glyph:
- * @font: (type PangoXftFont): a #PangoFont for the Xft backend
+ * @font: a #PangoFont for the Xft backend
  * @wc: Unicode codepoint to look up
  *
  * Gets the glyph index for a given Unicode character
@@ -627,7 +597,7 @@ pango_xft_font_get_glyph (PangoFont *font,
 
 /**
  * pango_xft_font_has_char:
- * @font: (type PangoXftFont): a #PangoFont for the Xft backend
+ * @font: a #PangoFont for the Xft backend
  * @wc: Unicode codepoint to look up
  *
  * Determines whether @font has a glyph for the codepoint @wc.
