@@ -104,7 +104,7 @@ parse_line (gchar *line,
         {
         case 0x00f7: /* DIVISION SIGN: boundary here */
           temp_attr.bits |= bits.bits;
-          G_GNUC_FALLTHROUGH;
+          /* fall through */
 
         case 0x00d7: /* MULTIPLICATION SIGN: no boundary here */
           break;
@@ -215,8 +215,9 @@ make_test_string (gchar *string,
 }
 
 static void
-do_test (const gchar *filename,
-         AttrBits bits)
+do_test (gchar *filename,
+         AttrBits bits,
+	 gboolean fixup_broken_linebreaktest)
 {
   GIOChannel *channel;
   GIOStatus status;
@@ -230,30 +231,32 @@ do_test (const gchar *filename,
 
   error = NULL;
   channel = g_io_channel_new_file (filename, "r", &error);
-  if (g_error_matches (error, G_FILE_ERROR, G_FILE_ERROR_NOENT))
+  if (!channel)
     {
-#if 0
-      g_test_skip ("Test file not found");
-#endif
-      return;
+      if (error->domain == G_FILE_ERROR && error->code == G_FILE_ERROR_NOENT)
+        {
+	  g_print ("%s not found.  Skipping test.\n", filename);
+	  goto done;
+	}
+      else
+        {
+	  g_printerr ("%s: %s\n", filename, error->message);
+	  exit (1);
+	}
     }
-
-  g_assert_no_error (error);
-
-  g_test_message ("Filename: %s", filename);
+  g_print ("Testing %s.\n", filename);
 
   i = 1;
   for (;;)
     {
       error = NULL;
       status = g_io_channel_read_line (channel, &line, &length, &terminator_pos, &error);
-      g_assert_no_error (error);
 
       switch (status)
         {
           case G_IO_STATUS_ERROR:
-            failed = TRUE;
-            goto done;
+            g_printerr ("%s: %s\n", filename, error->message);
+            exit (1);
 
           case G_IO_STATUS_EOF:
 	    goto done;
@@ -266,14 +269,23 @@ do_test (const gchar *filename,
             break;
         }
 
-      g_test_message ("Parsing line: %s", line);
-      g_assert_true (parse_line (line, bits, &string, &expected_attrs, &num_attrs));
+      if (! parse_line (line, bits, &string, &expected_attrs, &num_attrs))
+        {
+          g_printerr ("%s: error parsing line %d: %s\n", filename, i, line);
+          exit (1);
+        }
       
       if (num_attrs > 0)
         {
           PangoLogAttr *attrs = g_new (PangoLogAttr, num_attrs);
           pango_get_log_attrs (string, -1, 0, pango_language_from_string ("C"), attrs, num_attrs);
 
+	  /* LineBreakTest.txt from Unicode 5.1.0 has this bug that it says
+	   * breaking is allowed at the beginning of the strings, while the
+	   * algorithm says it's not.  Fix that up. */
+	  if (fixup_broken_linebreaktest)
+	    memset (expected_attrs, 0, sizeof (expected_attrs[0]));
+
           if (! attrs_equal (attrs, expected_attrs, num_attrs, bits))
             {
               gchar *str = make_test_string (string, attrs, bits);
@@ -288,10 +300,11 @@ do_test (const gchar *filename,
 		  comments = "";
 		}
 
-              g_test_message ("%s: line %d failed", filename, i);
-              g_test_message ("   expected: %s", line);
-              g_test_message ("   returned: %s", str);
-              g_test_message ("   comments: %s", comments);
+              g_printerr ("%s: line %d failed\n"
+                          "   expected: %s\n"
+                          "   returned: %s\n"
+			  "   comments: %s\n\n",
+                          filename, i, line, str, comments);
 
               g_free (str);
               failed = TRUE;
@@ -300,7 +313,6 @@ do_test (const gchar *filename,
         }
       g_free (string);
       g_free (expected_attrs);
-      g_free (line);
 
       i++;
     }
@@ -310,100 +322,43 @@ done:
     g_io_channel_unref (channel);
   if (error)
     g_error_free (error);
-
-  g_assert_true (!failed);
+  g_free (filename);
 }
 
-static void
-test_grapheme_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-  filename = g_test_get_filename (G_TEST_DIST, "GraphemeBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_cursor_position = 1;
-  do_test (filename, bits);
-}
-
-static void
-test_emoji_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-  filename = g_test_get_filename (G_TEST_DIST, "EmojiBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_cursor_position = 1;
-  do_test (filename, bits);
-}
-
-static void
-test_char_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-  filename = g_test_get_filename (G_TEST_DIST, "CharBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_char_break = 1;
-  do_test (filename, bits);
-}
-
-static void
-test_word_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-  filename = g_test_get_filename (G_TEST_DIST, "WordBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_word_boundary = 1;
-  do_test (filename, bits);
-}
-
-static void
-test_sentence_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-  filename = g_test_get_filename (G_TEST_DIST, "SentenceBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_sentence_boundary = 1;
-  do_test (filename, bits);
-}
-
-static void
-test_line_break (void)
-{
-  const char *filename;
-  AttrBits bits;
-
-
-  filename = g_test_get_filename (G_TEST_DIST, "LineBreakTest.txt", NULL);
-  bits.bits = 0;
-  bits.attr.is_line_break = 1;
-  bits.attr.is_mandatory_break = 1;
-
-  do_test (filename, bits);
-}
-
-
 gint
 main (gint argc,
       gchar **argv)
 {
+  gchar *srcdir;
+  gchar *filename;
+  AttrBits bits;
+
   setlocale (LC_ALL, "");
 
-  g_test_init (&argc, &argv, NULL);
+  srcdir = getenv ("srcdir");
+  if (!srcdir)
+    srcdir = ".";
 
-  g_test_add_func ("/text/break/grapheme", test_grapheme_break);
-  g_test_add_func ("/text/break/word", test_word_break);
-  g_test_add_func ("/text/break/sentence", test_sentence_break);
-  g_test_add_func ("/text/break/line", test_line_break);
-  g_test_add_func ("/text/break/emoji", test_emoji_break);
-  g_test_add_func ("/text/break/char", test_char_break);
+  filename = g_strdup_printf ("%s/GraphemeBreakTest.txt", srcdir);
+  bits.bits = 0;
+  bits.attr.is_cursor_position = 1;
+  do_test (filename, bits, FALSE);
 
-  return g_test_run ();
+  filename = g_strdup_printf ("%s/WordBreakTest.txt", srcdir);
+  bits.bits = 0;
+  bits.attr.is_word_boundary = 1;
+  do_test (filename, bits, FALSE);
+
+  filename = g_strdup_printf ("%s/SentenceBreakTest.txt", srcdir);
+  bits.bits = 0;
+  bits.attr.is_sentence_boundary = 1;
+  do_test (filename, bits, FALSE);
+
+  filename = g_strdup_printf ("%s/LineBreakTest.txt", srcdir);
+  bits.bits = 0;
+  bits.attr.is_line_break = 1;
+  bits.attr.is_mandatory_break = 1;
+  do_test (filename, bits, TRUE);
+
+  exit (failed);
 }
